@@ -13,23 +13,15 @@ sub usage_text {
 sub menu_txt {
     my ($self) = @_;
 
-    my $app = $self->app();
+    my $app = $self->get_app(); # metacommand is app-aware
 
-    # Build a numbered list of visible commands...
-    my @cmd = $app->get_interactive_commands();
-
-    my $txt;
-    my $augmented_aliases = $app->command_alias();
-    for my $i (0..$#cmd) {
-        $txt .= $i+1 . ') ' . $cmd[$i] . "\n";
-        $augmented_aliases->{$i+1} = $cmd[$i];
+    my $menu;
+    $menu = "\n" . '-'x13 . "menu" . '-'x13 . "\n";
+    for my $c ( $app->get_interactive_commands() ) {
+        $menu .= sprintf("\t%s\n", $c)
     }
-    # Add numerical aliases corresponding to menu options to the original
-    # command aliases defined by the application...
-    no strict 'refs'; no warnings;
-    *{ (ref $app).'::command_alias' } = sub { $augmented_aliases };
-
-    return "\n".$txt;
+    $menu .= '-'x30 . "\n";
+    return $menu;
 }
 
 #-------
@@ -50,12 +42,12 @@ A demonstration and test of overriding a built-in CLIF Menu command.
 =head1 NOTES
 
 This example replaces the built-in command menu.  The particular replacement
-is useless, but shows how such a replacement could be done.
+is not particularly useful, but shows how such a replacement could be done.
 
 Note that overriding the menu command is a special case of overriding a
 built-in command and it is necessary that the overriding command inherit from
 the built-in menu class, CLI::Framework::Command::Menu.
 
-This example just changes the way the menu looks.
+This example merely changes the menu format.
 
 =cut
